.. Copyright (c) Jupyter Development Team.
.. Distributed under the terms of the Modified BSD License.

Security Best Practices
=======================

Open Source Security (OpenSSF)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

The `Open Source Security (OpenSSF) <https://openssf.org/>`__ is a community focusing
to improve open source software security.

From that initiative, JupyterLab is improving its security by aligning with the
OpenSSF best practices and by monitoring them through an automated scored card.
